==> spirit_hub-0.0.1.8.tar.gz: spirit_hub-0.0.1.8/e2e/cypress/e2e/features/team_activities/team_activities.js <==
import { Given, When, Then } from '@badeball/cypress-cucumber-preprocessor';

Given('There is one collaborator and one manager', () => {
  cy.appFactories([['create', 'user', { email: 'manager@test.com', id: 'manager1', first_name: 'Jane' }]]);
  cy.appFactories([['create', 'team', { operators: ['1'], writers: ['manager1'] }]]);

  cy.appFactories([['create_list', 'tagset_doc', 2, 'with_file', 'with_state', { accounted: ['1'], state_key: 'to_sign' }]]);
  cy.appFactories([['create_list', 'tagset_doc', 1, 'with_file', 'with_state', { accounted: ['1'], state_key: 'to_validate' }]]);
  cy.appFactories([['create_list', 'tagset_doc', 3, 'with_file', 'with_state', { accounted: ['manager1'], state_key: 'to_complete' }]]);
  cy.appFactories([['create_list', 'tagset_doc', 2, 'with_file', 'with_state', { accounted: ['manager1'], state_key: 'to_answer' }]]);
});

Then('I should see the right columns', () => {
  cy.get('#model_table tbody tr:first td').eq(1).contains('Admin');
  cy.get('#model_table tbody tr:first td').eq(2).contains('2');
  cy.get('#model_table tbody tr:first td').eq(5).contains('1');
  cy.get('#model_table tbody tr:last td').eq(1).contains('Jane');
  cy.get('#model_table tbody tr:last td').eq(4).contains('3');
  cy.get('#model_table tbody tr:last td').eq(6).contains('2');
  cy.get('#model_table td').eq(7).find('a').should('exist');
});

When('I click on the collaborator view', () => {
  cy.get('#model_table tbody tr:first td:last a:first').click();
});

Then('I should see the collaborator documents', () => {
  cy.get('#model_table tbody tr:first td').eq(3).contains('Doc Title');
  cy.get('#model_table tbody tr:first td').eq(4).contains('7.1 Ko');
  cy.get('#model_table tbody tr:first td').eq(5).contains(new Date().toLocaleDateString('fr-FR'));
  cy.get('#model_table tbody tr:first td').eq(6).find('div').should('exist');
  cy.get('#model_table tbody tr:first td').eq(8).contains('À signer');
  cy.get('#model_table tbody tr:first td').eq(9).find('a').should('exist');
});

==> spirit_hub-0.1.1.6.tar.gz: spirit_hub-0.1.1.6/e2e/cypress/e2e/features/team_activities/team_activities.js <==
import { Given, When, Then } from '@badeball/cypress-cucumber-preprocessor';

Given('There is one collaborator and one manager', () => {
  cy.appFactories([['create', 'user', { email: 'manager@test.com', id: 'manager1', first_name: 'Jane' }]]);
  cy.appFactories([['create', 'team', { operators: ['1'], writers: ['manager1'] }]]);

  cy.appFactories([['create_list', 'tagset_doc', 2, 'with_file', 'with_state', { accounted: ['1'], state_key: 'to_sign' }]]);
  cy.appFactories([['create_list', 'tagset_doc', 1, 'with_state', { accounted: ['1'], state_key: 'to_validate' }]]);
  cy.appFactories([['create_list', 'tagset_doc', 3, 'with_state', { accounted: ['manager1'], state_key: 'to_complete' }]]);
  cy.appFactories([['create_list', 'tagset_doc', 2, 'with_state', { accounted: ['manager1'], state_key: 'to_answer' }]]);
});

Then('I should see the right columns', () => {
  cy.get('#model_table tbody tr:first td').eq(1).contains('Admin');
  cy.get('#model_table tbody tr:first td').eq(2).contains('2');
  cy.get('#model_table tbody tr:first td').eq(5).contains('1');
  cy.get('#model_table tbody tr:last td').eq(1).contains('Jane');
  cy.get('#model_table tbody tr:last td').eq(4).contains('3');
  cy.get('#model_table tbody tr:last td').eq(6).contains('2');
  cy.get('#model_table td').eq(7).find('a').should('exist');
});

When('I click on the collaborator view', () => {
  cy.get('#model_table tbody tr:first td:last a:first').click();
});

Then('I should see the collaborator documents', () => {
  cy.get('#model_table tbody tr:first td').eq(3).contains('Doc Title');
  cy.get('#model_table tbody tr:first td').eq(4).contains('7.1 Ko');
  cy.get('#model_table tbody tr:first td').eq(5).contains(new Date().toLocaleDateString('fr-FR'));
  cy.get('#model_table tbody tr:first td').eq(6).find('div').should('exist');
  cy.get('#model_table tbody tr:first td').eq(8).contains('À signer');
  cy.get('#model_table tbody tr:first td').eq(9).find('a').should('exist');
});
